@@ -68,7 +68,7 @@ def setup_logging(logger_name, log_file_name, loglevel=logging.DEBUG, log_output
     return logger
 
 
-def download_artifact(artifact_host, artifact_port, remote_path, project_id, original_artifacts_download_dir, artifact_name):
+def download_artifact(artifact_host, artifact_port, remote_path, project_system_id, original_artifacts_download_dir, artifact_name, token):
     """Download artifact
 
     Args:
@@ -91,13 +91,15 @@ def download_artifact(artifact_host, artifact_port, remote_path, project_id, ori
     try:
         #encode request params
 
-        request_params = urllib.parse.urlencode({"projectID": project_id})
+        request_params = urllib.parse.urlencode({"systemId": project_system_id})
 
         with open(artifact_path, "wb") as f:
             conn = http.client.HTTPConnection(artifact_host, artifact_port,  timeout=300)
 
             # request with query request_params
-            conn.request("GET", remote_path + "?" + request_params)
+            logger.info(f"token: {token}")
+
+            conn.request("GET", remote_path + "?" + request_params, headers={"X-Product-Token": token})
             response = conn.getresponse()
 
             logger.info(f"download artifacts response status is {response.status}")
